@@ -255,7 +255,7 @@ convert_identing(Tdocument * doc, gboolean to_tabs)
 
 	utf8_offset_cache_reset();
 	tabsize = doc_get_tabsize(doc);
-	/*g_print("got tabsize %d\n",tabsize); */
+	DEBUG_MSG("convert_identing, got tabsize %d\n",tabsize);
 	doc_unre_new_group(doc);
 	while (buf[i] != '\0') {
 		switch (buf[i]) {
@@ -292,6 +292,7 @@ convert_identing(Tdocument * doc, gboolean to_tabs)
 	}
 	g_free(buf);
 	doc_unre_new_group(doc);
+	DEBUG_MSG("convert_identing, done\n");
 }
 
 static void
