@@ -1,7 +1,7 @@
 /* Bluefish HTML Editor
  * external_commands.c - backend for external commands, filters and the outputbox
  *
- * Copyright (C) 2005-2014 Olivier Sessink
+ * Copyright (C) 2005-2024 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,8 +28,8 @@
 #include "bf_lib.h"
 #include "document.h"
 #include "gtk_easy.h"
-#include "outputbox.h"
 #include "dialog_utils.h"
+#include "bookmark.h"
 #include "external_commands.h"
 
 #ifndef WIN32
@@ -195,7 +195,7 @@ child_watch_lcb(GPid pid, gint status, gpointer data)
 	}
 	
 	if (ep->statuscode_cb) {
-		ep->statuscode_cb(status, BFWIN(ep->bfwin), ep->data);
+		ep->statuscode_cb(status, BFWIN(ep->bfwin), ep->commandstring, ep->data);
 	}
 
 	if (ep->pipe_in && !ep->buffer_out) {
@@ -615,17 +615,12 @@ create_commandstring(Texternalp * ep, const gchar * formatstr, gboolean discard_
 }
 
 static gboolean
-outputbox_io_watch_lcb(GIOChannel * channel, GIOCondition condition, gpointer data)
+per_line_io_watch_lcb(GIOChannel * channel, GIOCondition condition, gpointer data)
 {
 	Texternalp *ep = data;
-	DEBUG_MSG("outputbox_io_watch_lcb, called with condition %d\n", condition);
-	if (!ep->bfwin->outputbox) {
-		DEBUG_MSG("outputbox_io_watch_lcb, outputbox == NULL, close the channel\n");
-		g_io_channel_shutdown(channel, TRUE, NULL);
-		externalp_unref(ep);
+	if (!ep->customcommand_cb)
 		return FALSE;
-	}
-
+	DEBUG_MSG("per_line_io_watch_lcb, called with condition %d\n", condition);
 	if (condition & G_IO_IN) {
 		gchar *buf = NULL;
 		gsize buflen = 0, termpos = 0;
@@ -635,14 +630,14 @@ outputbox_io_watch_lcb(GIOChannel * channel, GIOCondition condition, gpointer da
 			if (buflen > 0) {
 				if (termpos < buflen)
 					buf[termpos] = '\0';
-				fill_output_box(ep->bfwin->outputbox, buf);
+				ep->customcommand_cb(buf, ep->bfwin, ep->data);
 				ep->havedata = TRUE;
 			}
 			g_free(buf);
 			status = g_io_channel_read_line(channel, &buf, &buflen, &termpos, &gerror);
 		}
 		if (gerror) {
-			g_warning("error while trying to read data for outputbox, %d: %s\n", gerror->code,
+			g_warning("error while trying to read data for per_line, %d: %s\n", gerror->code,
 					  gerror->message);
 			g_error_free(gerror);
 		}
@@ -655,28 +650,29 @@ outputbox_io_watch_lcb(GIOChannel * channel, GIOCondition condition, gpointer da
 		}
 	}
 	if (condition & G_IO_OUT) {
-		DEBUG_MSG("outputbox_io_watch_lcb, condition %d G_IO_OUT not handled\n", condition);
+		DEBUG_MSG("per_line_io_watch_lcb, condition %d G_IO_OUT not handled\n", condition);
 	}
 	if (condition & G_IO_PRI) {
-		DEBUG_MSG("outputbox_io_watch_lcb, condition %d G_IO_PRI not handled\n", condition);
+		DEBUG_MSG("per_line_io_watch_lcb, condition %d G_IO_PRI not handled\n", condition);
 	}
 	if (condition & G_IO_ERR) {
-		DEBUG_MSG("outputbox_io_watch_lcb, condition %d G_IO_ERR not handled\n", condition);
+		DEBUG_MSG("per_line_io_watch_lcb, condition %d G_IO_ERR not handled\n", condition);
 	}
 	if (condition & G_IO_HUP) {
 		GError *error = NULL;
-		DEBUG_MSG("outputbox_io_watch_lcb, condition %d G_IO_HUP\n", condition);
+		DEBUG_MSG("per_line_io_watch_lcb, condition %d G_IO_HUP\n", condition);
 		/* cleanup !!!!!!!!! */
 		g_io_channel_shutdown(channel, TRUE, &error);
 		externalp_unref(ep);
 		return FALSE;
 	}
 	if (condition & G_IO_NVAL) {
-		DEBUG_MSG("outputbox_io_watch_lcb, condition %d G_IO_NVAL not handled\n", condition);
+		DEBUG_MSG("per_line_io_watch_lcb, condition %d G_IO_NVAL not handled\n", condition);
 	}
 	return TRUE;
 }
 
+
 static gboolean
 full_data_io_watch_lcb(GIOChannel * channel, GIOCondition condition, gpointer data)
 {
@@ -797,48 +793,26 @@ command_backend(Tbfwin * bfwin, gint begin, gint end,
 	start_command(ep);
 }
 
-static void
-filter_statuscode_lcb(gint status, Tbfwin * bfwin, gpointer data)
+void
+generic_statuscode_lcb(gint status, Tbfwin * bfwin, const gchar *commandstring, gpointer data)
 {
-	Texternalp *ep = data;
-	DEBUG_MSG("filter_statuscode_lcb, exitcode %d\n", status);
+	DEBUG_MSG("generic_statuscode_lcb, exitcode %d\n", status);
 #ifndef WIN32
 	/* on windows this even fires dialogs when opening something in firefox, disabling that for the moment */
 	if (status != 0) {
 		gchar *tmp =
-			g_markup_printf_escaped(_("The command %s exited with error code %d. %s"), ep->commandstring,
+			g_markup_printf_escaped(_("The command %s exited with error code %d. %s"), commandstring,
 									status,
 									(status ==
 									 32512) ? _("Probably this application is not installed on your system.")
 									: "");
-		message_dialog_new(BFWIN(ep->bfwin)->main_window, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
+		message_dialog_new(BFWIN(bfwin)->main_window, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 						   _("Command returned error code"), tmp);
 		g_free(tmp);
 	}
 #endif
 }
 
-static void
-outputbox_statuscode_lcb(gint status, Tbfwin * bfwin, gpointer data)
-{
-	Texternalp *ep = data;
-	gchar *tmp =
-		g_strdup_printf(_("The command %s exited with error code %d. %s"), ep->commandstring, status, "");
-	DEBUG_MSG("outputbox_statuscode_lcb, exitcode %d, add to outputbox: %s\n", status, tmp);
-	fill_output_box(bfwin->outputbox, tmp);
-	if (status == 32512) {
-		fill_output_box(bfwin->outputbox, _("Probably this application is not installed on your system."));
-	}
-	g_free(tmp);
-}
-
-void
-outputbox_command(Tbfwin * bfwin, const gchar * formatstring)
-{
-	command_backend(bfwin, 0, -1, formatstring, outputbox_io_watch_lcb, TRUE, outputbox_statuscode_lcb, NULL,
-					NULL);
-}
-
 static void
 filter_custom_lcb(const gchar * str_return, gpointer bfwin, gpointer data)
 {
@@ -855,7 +829,9 @@ filter_custom_lcb(const gchar * str_return, gpointer bfwin, gpointer data)
 		line = gtk_text_iter_get_line(&iter);
 		offset = gtk_text_iter_get_line_offset(&iter);
 	}
+	bmark_clean_for_doc(BFWIN(bfwin)->current_document);
 	doc_replace_text(BFWIN(bfwin)->current_document, str_return, ep->begin, end);
+	bmark_set_for_doc(BFWIN(bfwin)->current_document, TRUE);
 	if (line != -1) {
 		if (gtk_text_buffer_get_line_count(buffer) >= line) {
 			gtk_text_buffer_get_iter_at_line(buffer, &iter, line);
@@ -872,7 +848,7 @@ filter_custom_lcb(const gchar * str_return, gpointer bfwin, gpointer data)
 void
 filter_command(Tbfwin * bfwin, const gchar * formatstring, gint begin, gint end)
 {
-	command_backend(bfwin, begin, end, formatstring, full_data_io_watch_lcb, FALSE, filter_statuscode_lcb,
+	command_backend(bfwin, begin, end, formatstring, full_data_io_watch_lcb, FALSE, generic_statuscode_lcb,
 					filter_custom_lcb, NULL);
 }
 
@@ -886,7 +862,7 @@ external_custom_lcb(const gchar * str_return, gpointer bfwin, gpointer data)
 void
 external_command(Tbfwin * bfwin, const gchar * formatstring)
 {
-	command_backend(bfwin, 0, -1, formatstring, full_data_io_watch_lcb, FALSE, filter_statuscode_lcb, external_custom_lcb, NULL);
+	command_backend(bfwin, 0, -1, formatstring, full_data_io_watch_lcb, FALSE, generic_statuscode_lcb, external_custom_lcb, NULL);
 }
 
 void
@@ -894,3 +870,11 @@ custom_command(Tbfwin * bfwin, const gchar * formatstring, CustomCommandCallback
 {
 	command_backend(bfwin, 0, -1, formatstring, full_data_io_watch_lcb, TRUE, NULL, func, data);
 }
+
+/* same as custom_command(), except it calls CustomCommandCallback for each line */
+void
+custom_command_lines(Tbfwin * bfwin, const gchar * formatstring, StatusCodeCallback statuscode_cb, CustomCommandCallback customcommand_cb, gpointer data)
+{
+	command_backend(bfwin, 0, -1, formatstring, per_line_io_watch_lcb, TRUE, statuscode_cb, customcommand_cb, data);
+}
+
