@@ -1541,12 +1541,9 @@ openadv_content_filter_file(Topenadvanced * oa, GFile * uri, GFileInfo * finfo)
 {
 	Topenadvanced_uri *oau;
 	Tdocument *tmpdoc;
-	GList *alldocs;
 
 	/* don't content filter if the file is an already opened document */
-	alldocs = return_allwindows_documentlist();
-	tmpdoc = documentlist_return_document_from_uri(alldocs, uri);
-	g_list_free(alldocs);
+	tmpdoc = documentlist_return_document_from_uri(uri);
 	if (tmpdoc)
 		return;
 
