@@ -612,11 +612,9 @@ ask_new_filename(Tbfwin * bfwin, const gchar * old_curi, const gchar *dialogtext
 		return NULL;
 	}
 
-	alldocs = return_allwindows_documentlist();
 	uri = g_file_new_for_uri(new_curi);
-	exdoc = documentlist_return_document_from_uri(alldocs, uri);
+	exdoc = documentlist_return_document_from_uri(uri);
 	g_object_unref(uri);
-	g_list_free(alldocs);
 	DEBUG_MSG("ask_new_filename, exdoc=%p, newfilename=%s\n", exdoc, new_curi);
 	if (exdoc) {
 		gchar *tmpstr;
