@@ -1107,6 +1107,10 @@ file_but_clicked_lcb(GtkWidget * widget, Tfilebut * fb)
 			setfile = g_file_get_uri(newsetfile);
 			g_object_unref(newsetfile);
 		}
+	} else {
+		GFile *uri = g_file_new_for_commandline_arg(setfile);
+		g_free(setfile);
+		setfile = g_file_get_uri(uri);
 	}
 
 	if (!fb->fullpath && fb->bfwin && fb->bfwin->current_document && fb->bfwin->current_document->uri) {
@@ -1297,7 +1301,7 @@ file_chooser_dialog(Tbfwin * bfwin, const gchar * title, GtkFileChooserAction ac
 		} else {
 			gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(dialog), set);
 		}
-	} else if (!localonly && bfwin) {	/* localonly is used for the project files */
+	} else if (!localonly && bfwin) {	/* localonly is used for the project files, import/export snippets, etc. */
 		if (action == GTK_FILE_CHOOSER_ACTION_SAVE) {
 			DEBUG_MSG("file_chooser_dialog, opendir=%s, savedir=%s\n", bfwin->session->opendir,
 					  bfwin->session->savedir);
