@@ -385,17 +385,11 @@ fill_output_box(gpointer data, gchar * string)
 		}
 		DEBUG_MSG("fill_output_box, filename=%s, line=%s, output=%s\n", filename, line, output);
 		if (filename) {
-			GFile *addtolist;
 			gchar *curi;
-			if (filename[0] == '/' || strchr(filename, ':') != NULL) {
-				addtolist = g_file_new_for_commandline_arg(filename);
-			} else {
-				GFile *docparent = g_file_get_parent(ob->def->docuri);
-				addtolist = g_file_resolve_relative_path(docparent, filename);
-				g_object_unref(docparent);
-			}
+			GFile *docparent = g_file_get_parent(ob->def->docuri);
+			GFile *addtolist = uri_from_external_input(filename, docparent);
+			g_object_unref(docparent);
 			curi = g_file_get_uri(addtolist);
-
 			gtk_list_store_set(GTK_LIST_STORE(ob->lstore), &iter, 0, curi, -1);
 			g_free(curi);
 			g_object_unref(addtolist);
@@ -473,6 +467,25 @@ outputbox_clear(Tbfwin *bfwin)
 	}
 }
 
+static void
+outputbox_external_command_lcb(const gchar *output, gpointer bfwin, gpointer data) {
+	fill_output_box(OUTPUTBOX(BFWIN(bfwin)->outputbox), output);
+}
+
+static void
+outputbox_statuscode_lcb(gint status, Tbfwin * bfwin, const gchar *commandstring, gpointer data)
+{
+	if (status == 0)
+		return;
+	gchar *tmp =
+		g_strdup_printf(_("The command %s exited with error code %d"), commandstring, status);
+	fill_output_box(bfwin->outputbox, tmp);
+	if (status == 32512) {
+		fill_output_box(bfwin->outputbox, _("Probably this application is not installed on your system."));
+	}
+	g_free(tmp);
+}
+
 void
 outputbox(Tbfwin * bfwin, gchar * pattern, gint file_subpat, gint line_subpat, gint output_subpat,
 		  gchar * command)
@@ -521,5 +534,6 @@ outputbox(Tbfwin * bfwin, gchar * pattern, gint file_subpat, gint line_subpat, g
 		ob->def->reg = NULL;
 		return;
 	}
-	outputbox_command(bfwin, command);
+	
+	custom_command_lines(bfwin, command, outputbox_statuscode_lcb, outputbox_external_command_lcb, ob);
 }
