@@ -2,7 +2,7 @@
  * about.c - the About dialog
  *
  * Copyright (C) 2004 Eugene Morenko(More) more@irpin.com
- * Copyright (C) 2008-2014 Olivier Sessink
+ * Copyright (C) 2008-2024 Olivier Sessink
  * Copyright (C) 2011 James Hayward
  *
  * This program is free software; you can redistribute it and/or modify
@@ -38,6 +38,51 @@
 #include "../config.h"
 #include "../plugins.h"
 #include "../bluefish.h"		/* BLUEFISH_SPLASH_FILENAME */
+#include "../languages.h"
+#include "../rcfile.h"
+
+Tabout about_v = {0, 0};
+
+static void translation_warning_dialog_response_lcb(GtkDialog *dialog,int response_id,GtkWidget *ignorelabel) {
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(ignorelabel))) {
+		about_v.ignore_2_2_16_translation_message = 1;
+		/*g_print("ignore translation message\n");*/
+	}
+	gtk_widget_destroy(GTK_WIDGET(dialog));
+}
+
+static gboolean 
+show_translation_warning_dialog(gpointer data) {
+	const gchar *locale = getenv("LANG");
+	/* no need to make these strings translatable: this is only shown for languages that are not translated!!!!!!! */
+	GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(data), GTK_DIALOG_DESTROY_WITH_PARENT, 
+			GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, 
+			"You are running Bluefish on a system with language %s. Unfortunately Bluefish "PACKAGE_VERSION" does not have an up-to-date translation for %s. Bluefish is made by volunteers. If you can help to translate Bluefish to your language, please send a message to olivier@bluefish.openoffice.nl", locale, locale);
+	GtkWidget *box = gtk_message_dialog_get_message_area(GTK_MESSAGE_DIALOG(dialog));
+	GtkWidget *ignorelabel = gtk_check_button_new_with_label("Ignore this message for Bluefish "PACKAGE_VERSION);
+	gtk_box_pack_end(GTK_BOX(box), ignorelabel, TRUE, TRUE, 5);
+	g_signal_connect(G_OBJECT(dialog), "response", G_CALLBACK(translation_warning_dialog_response_lcb), ignorelabel);
+	gtk_window_set_transient_for(GTK_WINDOW(dialog),GTK_WINDOW(data));
+	gtk_widget_show_all(GTK_WIDGET(dialog));
+	return FALSE; 
+}
+
+
+static gboolean
+needs_translation_warning_message() {
+	const gchar *locale = getenv("LANG");
+	/*g_print("needs_translation_warning_message, check %s\n",locale);*/
+	if (!locale || locale[0]=='\0')
+		return FALSE;
+	gchar *localestripped = g_strdup(locale);
+	gchar *ptr = strchr(localestripped, '.');
+	if (ptr)
+		*ptr='\0';
+	gboolean up2date = lingua_locale_is_uptodate(localestripped);
+	g_free(localestripped);
+	lingua_cleanup();
+	return !up2date;
+}
 
 
 static void
@@ -176,28 +221,30 @@ about_dialog_create(GtkAction * action, gpointer user_data)
 
 	const gchar *authors[] = {
 		"Olivier Sessink <olivier@bluefish.openoffice.nl> (Project leader)",
-		"Andrius <andriusr@yahoo.com>",
-		"Jim Hayward <jimhayward@linuxexperience.net>",
-		"Daniel Leidert <daniel.leidert@wgdd.de>",
-		"Shawn Novak <kernel86@gmail.com>",
-		"Frédéric Falsetti <falsetti@clansco.org>",
 		_("\nDevelopers of previous releases:"),
 		"Alastair Porter <alastair@porter.net.nz>",
+		"Andrius Rinkevicius <andriusrin@gmail.com>",
 		"Antti-Juhani Kaijanaho",
 		"Bo Forslund",
 		"Chris Mazuc",
 		"Christian Tellefsen <chris@tellefsen.net>",
+		"Daniel Leidert <daniel.leidert@wgdd.de>",
 		"David Arno",
+		"Dieter Michaelis <dimic@gmx.net>",
 		"Eugene Morenko <more@irpin.com>",
+		"Frédéric Falsetti <falsetti@clansco.org>",
 		"Gero Takke",
+		"Jim Hayward <jimhayward@linuxexperience.net>",
 		"Neil Millar",
+		"Nuno Teixeira <eduardo@freebsd.org>",
 		"Oskar Świda <swida@aragorn.pb.bialystok.pl>",
 		"Pablo De Napoli",
 		"Rasmus Toftdahl Olesen <rto@pohldata.dk>",
 		"Roland Steinbach <roland@netzblick.de>",
 		"Santiago Capel Torres",
+		"Shawn Novak <kernel86@gmail.com>",
 		"Yanike Mann <yanikem@gmail.com>",
-		_("\nPackage maintainers:"),
+/*		_("\nPackage maintainers:"),*/
 		"Debian: Daniel Leidert <daniel.leidert@wgdd.de>",
 		"Fink: Michèle Garoche <michele.garoche@easyconnect.fr>, Kevin Horton <khorton01@rogers.com>",
 		"Gentoo: Hanno Böck <hanno@gentoo.org>",
@@ -221,7 +268,7 @@ about_dialog_create(GtkAction * action, gpointer user_data)
 		NULL
 	};
 
-	const gchar *copyright = "Copyright \xc2\xa9 1998-2020 Olivier Sessink and others.\n";
+	const gchar *copyright = "Copyright \xc2\xa9 1998-2024 Olivier Sessink and others.\n";
 
 	/* wrap the license here,
 	 * the "wrap-license" property is only available with GTK >= 2.8
@@ -371,6 +418,14 @@ about_initgui(Tbfwin * bfwin)
 		g_warning("building about plugin menu failed: %s", error->message);
 		g_error_free(error);
 	}
+	/*g_print("about_v.tested_2_2_16_translation_status=%d about_v.ignore_2_2_16_translation_message=%d\n",about_v.tested_2_2_16_translation_status, about_v.ignore_2_2_16_translation_message);*/
+	if (about_v.tested_2_2_16_translation_status==0 && about_v.ignore_2_2_16_translation_message==0) {
+		if (needs_translation_warning_message()) {
+			g_timeout_add_seconds(1,show_translation_warning_dialog, bfwin->main_window);
+		} else {
+			about_v.tested_2_2_16_translation_status=1;
+		}
+	}
 }
 
 /*static void
@@ -388,11 +443,14 @@ about_cleanup_gui(Tbfwin * bfwin)
 {
 }
 */
-/*static GHashTable *
-about_register_globses_config(GHashTable * configlist)
+
+static GHashTable *
+about_register_globses_config(GHashTable * hasht)
 {
-	return configlist;
-}*/
+	hasht = make_config_list_item(hasht, &about_v.ignore_2_2_16_translation_message, 'i', "ignore_2_2_16_translation_message:", 0);
+	hasht = make_config_list_item(hasht, &about_v.tested_2_2_16_translation_status, 'i', "test_2_2_16_translation_status:",0);
+	return hasht;
+}
 
 /*static GHashTable *
 about_register_session_config(GHashTable * configlist, Tsessionvars * session)
@@ -404,7 +462,7 @@ G_MODULE_EXPORT TBluefishPlugin *
 getplugin(void)
 {
 	static TBluefishPlugin bfplugin = {
-		"About Dialog",
+		N_("About Dialog"),
 		BFPLUGIN_VERSION,
 		GTK_MAJOR_VERSION,
 		sizeof(Tdocument),
@@ -422,11 +480,11 @@ getplugin(void)
 		NULL /*about_enforce_session*/,
 		NULL /*about_cleanup*/,
 		NULL /*about_cleanup_gui*/,
-		NULL /*about_register_globses_config*/,
+		about_register_globses_config,
 		NULL /*about_register_session_config*/,
+		NULL /*about_session_cleanup */,
 		NULL,						/* binary compatibility */
 		NULL,
-		NULL,
 		NULL
 	};
 	return &bfplugin;
