@@ -35,6 +35,7 @@ typedef struct {
 	PyObject_HEAD
 	char *profile;
 	Tdocument *context;
+	PyObject *utils;
 } Tzeneditor;
 
 /**********************************/
@@ -130,10 +131,11 @@ zeneditor_set_caret_pos(Tzeneditor *self, PyObject *args)
 	gint offset;
 	if (PyArg_ParseTuple(args, "i", &offset)) {
 		GtkTextIter itstart;
+		DEBUG_MSG("zeneditor_set_caret_pos, %d\n",offset);
 		gtk_text_buffer_get_iter_at_offset(DOCUMENT(self->context)->buffer, &itstart, offset);
 		gtk_text_buffer_place_cursor(DOCUMENT(self->context)->buffer,&itstart);
 	}
-
+	DEBUG_MSG("zeneditor_set_caret_pos, none\n");
 	Py_RETURN_NONE;
 }
 
@@ -162,10 +164,11 @@ static inline const gchar *
 get_caret_placeholder(PyObject *mod) {
 	const gchar *retval;
 	/*PyObject *pcaret_placeholder = PyObject_GetAttrString(mod, "caret_placeholder");*/
-	PyObject *pcaret_placeholder = PyObject_CallMethod(mod, "getCaretPlaceholder", NULL);
+	/*PyObject *pcaret_placeholder = PyObject_CallMethod(mod, "getCaretPlaceholder", NULL);*/
+	PyObject *pcaret_placeholder = PyObject_CallMethod(mod, "get_caret_placeholder", NULL);
 	if (!pcaret_placeholder) {
 		if (PyErr_Occurred()) PyErr_Print();
-		DEBUG_MSG("failed to get placeholder\n");
+		DEBUG_MSG("get_caret_placeholder, failed to get placeholder, return {%::zen-caret::%}\n");
 		return "{%::zen-caret::%}";
 	}
 #ifdef IS_PY3K
@@ -174,6 +177,7 @@ get_caret_placeholder(PyObject *mod) {
 	Py_DECREF(pyStr);
 #else
 	retval = (const gchar *)PyString_AsString(pcaret_placeholder);
+	DEBUG_MSG("get_caret_placeholder, return %s\n",retval);
 #endif
 	Py_DECREF(pcaret_placeholder);
 	return retval;
@@ -185,7 +189,7 @@ remove_placeholder(const gchar *input, const gchar *ph, gint *first_ph_pos)
 	GString *retstr;
 	gchar *found, *pos;
 	gint phlen;
-	
+	DEBUG_MSG("remove_placeholder, ph=%s\n",ph);
 	found = g_strstr_len(input, -1, ph);
 	if (!found) {
 		return g_strdup(input);
@@ -222,7 +226,7 @@ zeneditor_replace_content(Tzeneditor *self, PyObject *args)
 		if only end is -1 we insert starting at the current cursor position
 		
 		we also have to check if there is a caret placeholder in 'text' */
-		placeholder = get_caret_placeholder(zencoding.module);
+		placeholder = get_caret_placeholder(self->utils);
 		toinsert = remove_placeholder(text, placeholder, &new_caret_position);
 
 		if (start == -1 && end == -1) { /* overwrite everything */
@@ -416,6 +420,7 @@ zeneditor_init(Tzeneditor *self, PyObject *args, PyObject *kwds)
 		return -1;
 	}
 	Py_XDECREF(mod);
+	self->utils = mod;
 	return 0;
 }
 
