@@ -1,7 +1,7 @@
 /* Bluefish HTML Editor
  * snr3.c - search and replace
  *
- * Copyright (C) 2011,2012,2013,2014,2017,2019,2020 Olivier Sessink
+ * Copyright (C) 2011,2012,2013,2014,2017,2019,2020,2024 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -369,7 +369,7 @@ static Tsnr3result * sn3run_add_result(Tsnr3run *s3run, gulong so, gulong eo, gp
 	g_queue_push_tail(&s3run->results, s3result);
 	if (s3run->showinoutputbox && doc && DOCUMENT(doc)->uri) {
 		GtkTextIter it1, it2, it3, it4, tmpit;
-		gchar *curi, *text, *prefix, *match, *suffix;
+		gchar *curi, *text, *prefix, *match, *suffix=NULL, *prefix_es=NULL, *match_es=NULL, *suffix_es=NULL;
 		guint line;
 		curi = g_file_get_uri(DOCUMENT(doc)->uri);
 		gtk_text_buffer_get_iter_at_offset(DOCUMENT(doc)->buffer, &it2, so);
@@ -392,17 +392,24 @@ static Tsnr3result * sn3run_add_result(Tsnr3run *s3run, gulong so, gulong eo, gp
 				gtk_text_iter_forward_chars(&it4, 40);
 			}
 		}
-		/*text = gtk_text_buffer_get_text(DOCUMENT(doc)->buffer, &it1, &it2, TRUE);*/
 		prefix = gtk_text_buffer_get_text(DOCUMENT(doc)->buffer, &it1, &it2, TRUE);
 		match = gtk_text_buffer_get_text(DOCUMENT(doc)->buffer, &it2, &it3, TRUE);
 		suffix = gtk_text_buffer_get_text(DOCUMENT(doc)->buffer, &it3, &it4, TRUE);
-		text = g_strconcat(prefix?prefix:"", "<b>", match?match:"","</b>", suffix?suffix:"", NULL);
+		
+		prefix_es = g_markup_escape_text(prefix,-1);
+		match_es = g_markup_escape_text(match,-1);
+		suffix_es = g_markup_escape_text(suffix,-1);
+		text = g_strconcat(prefix_es, "<b>", match?match_es:"","</b>", suffix_es, NULL);
+		DEBUG_MSG("about to call outputbox_add_line_markup() with line %d and text %s\n",line, text);
 		outputbox_add_line_markup(s3run->bfwin, curi, line, text);
 		g_free(curi);
 		g_free(text);
 		g_free(prefix);
 		g_free(suffix);
 		g_free(match);
+		g_free(prefix_es);
+		g_free(suffix_es);
+		g_free(match_es);
 	}
 	return s3result;
 }
@@ -670,6 +677,7 @@ replace_all_buttons(Tsnr3run *s3run, gboolean enable)
 	gtk_widget_set_sensitive(((TSNRWin *)s3run->dialog)->backButton, enable);
 	gtk_widget_set_sensitive(((TSNRWin *)s3run->dialog)->replaceAllButton, enable);
 	gtk_widget_set_sensitive(((TSNRWin *)s3run->dialog)->bookmarkButton, enable);
+	gtk_widget_set_sensitive(((TSNRWin *)s3run->dialog)->bookmarkpermanent, enable);
 }
 
 void
@@ -904,7 +912,7 @@ void snr3run_bookmark_all(Tsnr3run *s3run) {
 	for (tmpl=g_list_first(s3run->results.head);tmpl;tmpl=g_list_next(tmpl)) {
 		Tsnr3result *s3result = tmpl->data;
 		gchar *text = doc_get_chars(s3result->doc, s3result->so, s3result->eo);
-		bmark_add_extern(s3result->doc, s3result->so, s3run->query, text, !main_v->globses.bookmarks_default_store);
+		bmark_add_extern(BFWIN(DOCUMENT(s3result->doc)->bfwin), s3result->doc, s3result->so, s3run->query, text, !s3run->bookmarkpermanent, s3run->bookmarkpermanent?NULL:"#774444");
 		g_free(text);
 	}
 }
@@ -1248,7 +1256,7 @@ static gint
 snr3run_init_from_gui(TSNRWin *snrwin, Tsnr3run *s3run)
 {
 	const gchar *query, *replace;
-	gint type, replacetype, scope, dotmatchall, escapechars, recursion_level, showinoutputbox, ignorebackupfiles;
+	gint type, replacetype, scope, dotmatchall, escapechars, recursion_level, showinoutputbox, ignorebackupfiles, bookmarkpermanent;
 	gboolean is_case_sens;
 	gint retval=0;
 	gchar *cbasedir;
@@ -1268,6 +1276,7 @@ snr3run_init_from_gui(TSNRWin *snrwin, Tsnr3run *s3run)
 	showinoutputbox = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(snrwin->showinoutputbox));
 	ignorebackupfiles = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(snrwin->ignorebackupfiles));
 	escapechars = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(snrwin->escapeChars));
+	bookmarkpermanent = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(snrwin->bookmarkpermanent));
 	recursion_level = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(snrwin->recursion_level));
 
 	cbasedir = gtk_entry_get_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(snrwin->basedir))));
@@ -1320,6 +1329,11 @@ snr3run_init_from_gui(TSNRWin *snrwin, Tsnr3run *s3run)
 		s3run->ignorebackupfiles = ignorebackupfiles;
 		retval |= 1;
 	}
+	if (bookmarkpermanent != s3run->bookmarkpermanent) {
+		/* no need to cancel anything, this only infuenced the bookmarkall button */
+		s3run->bookmarkpermanent = bookmarkpermanent;
+	}
+
 	if (escapechars != s3run->escape_chars) {
 		snr3_cancel_run(s3run);
 		s3run->escape_chars = escapechars;
@@ -1544,6 +1558,7 @@ static void snr_dialog_show_widgets(TSNRWin * snrwin) {
 	widget_set_visible(snrwin->backButton, (scope != snr3scope_files));
 	widget_set_visible(snrwin->findButton, (scope != snr3scope_files));
 	widget_set_visible(snrwin->bookmarkButton, (scope != snr3scope_files));
+	widget_set_visible(snrwin->bookmarkpermanent, (scope != snr3scope_files));
 }
 
 static void
@@ -1625,7 +1640,7 @@ snr3_advanced_dialog_backend(Tbfwin * bfwin, const gchar *findtext, Tsnr3scope s
 	vbox = gtk_dialog_get_content_area(GTK_DIALOG(snrwin->dialog));
 
 	table =
-		dialog_table_in_vbox(3, 7, 6/*borderwidth*/, vbox, TRUE,
+		dialog_table_in_vbox(3, 10, 6/*borderwidth*/, vbox, TRUE,
 							 TRUE, 0);
 	gtk_table_set_row_spacings(GTK_TABLE(table), 4);
 	currentrow=0;
@@ -1783,25 +1798,13 @@ snr3_advanced_dialog_backend(Tbfwin * bfwin, const gchar *findtext, Tsnr3scope s
 	snrwin->ignorebackupfiles = dialog_check_button_in_table(_("Ignore backup files"), bfwin->session->snr3_ignorebackupfiles, table,
 										0, 2, currentrow, currentrow+1);
 	gtk_widget_set_tooltip_text(snrwin->ignorebackupfiles, _("Ignore backup files *~ created by Bluefish"));
+	
+	currentrow++;
 
+	snrwin->bookmarkpermanent = dialog_check_button_in_table(_("Make bookmarks permanent"), bfwin->session->snr3_bookmarkpermanent, table,
+										0, 2, currentrow, currentrow+1);
+	gtk_widget_set_tooltip_text(snrwin->ignorebackupfiles, _("Ignore backup files *~ created by Bluefish"));
 
-/*	snrwin->overlappingMatches = gtk_check_button_new_with_mnemonic(_("Allow o_verlapping matches"));
-	gtk_box_pack_start(GTK_BOX(vbox2), snrwin->overlappingMatches, FALSE, FALSE, 0);
-	g_signal_connect(snrwin->overlappingMatches, "toggled", G_CALLBACK(snr_option_toggled), snrwin);
-	gtk_widget_set_tooltip_text(snrwin->overlappingMatches,
-								_("After a match is found, start next search within that match."));
-
-
-	snrwin->select_match = gtk_check_button_new_with_mnemonic(_("Select matc_hes"));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(snrwin->select_match), main_v->globses.snr_select_match);
-	gtk_box_pack_start(GTK_BOX(vbox2), snrwin->select_match, FALSE, FALSE, 0);
-	gtk_widget_set_tooltip_text(snrwin->select_match,
-								_("Select the matching text instead of just highlighting it"));
-
-	snrwin->bookmarks = gtk_check_button_new_with_mnemonic(_("_Bookmark matches"));
-	gtk_box_pack_start(GTK_BOX(vbox2), snrwin->bookmarks, FALSE, FALSE, 0);
-	gtk_widget_set_tooltip_text(snrwin->bookmarks, _("Create a bookmark for each match"));
-*/
 	gtk_dialog_add_button(GTK_DIALOG(snrwin->dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
 	snrwin->replaceAllButton =
 			gtk_dialog_add_button(GTK_DIALOG(snrwin->dialog), _("Replace _All"), SNR_RESPONSE_REPLACE_ALL);
@@ -1845,6 +1848,7 @@ snr3_advanced_dialog_backend(Tbfwin * bfwin, const gchar *findtext, Tsnr3scope s
 	g_signal_connect(snrwin->showinoutputbox, "toggled", G_CALLBACK(snr_option_toggled), snrwin);
 	g_signal_connect(snrwin->ignorebackupfiles, "toggled", G_CALLBACK(snr_option_toggled), snrwin);
 	g_signal_connect(snrwin->dotmatchall, "toggled", G_CALLBACK(snr_option_toggled), snrwin);
+	g_signal_connect(snrwin->bookmarkpermanent, "toggled", G_CALLBACK(snr_option_toggled), snrwin);
 
 	snr_dialog_show_widgets(snrwin);
 
