@@ -436,7 +436,7 @@ static void filematch_cb(Tsnr3run *s3run, GFile *uri, GFileInfo *finfo) {
 	
 	/* TODO: first check if we have this file open, in that case we have to run the
 	function that replaces in the document */
-	doc = documentlist_return_document_from_uri(s3run->bfwin->documentlist, uri);
+	doc = documentlist_return_document_from_uri(uri);
 	if (doc) {
 		DEBUG_MSG("filematch_cb, this file is already open, use snr3_run_in_doc()\n");
 		snr3_run_in_doc(s3run, doc, 0, -1, FALSE);
